@@ -505,10 +505,6 @@ from bitmovin_api_sdk.models.nex_guard_watermarking_type import NexGuardWatermar
 from bitmovin_api_sdk.models.notification import Notification
 from bitmovin_api_sdk.models.notification_state_entry import NotificationStateEntry
 from bitmovin_api_sdk.models.notification_states import NotificationStates
-from bitmovin_api_sdk.models.object_detection_bounding_box import ObjectDetectionBoundingBox
-from bitmovin_api_sdk.models.object_detection_configuration import ObjectDetectionConfiguration
-from bitmovin_api_sdk.models.object_detection_result import ObjectDetectionResult
-from bitmovin_api_sdk.models.object_detection_timestamp_result import ObjectDetectionTimestampResult
 from bitmovin_api_sdk.models.opus_audio_configuration import OpusAudioConfiguration
 from bitmovin_api_sdk.models.opus_channel_layout import OpusChannelLayout
 from bitmovin_api_sdk.models.or_conjunction import OrConjunction
